import os
import ctypes
from pystyle import Colors

class console:
    def clear():
        os.system('cls' if os.name == 'nt' else 'clear')
    
    def title(text):
        ctypes.windll.kernel32.SetConsoleTitleW(text)

    class log:
        @staticmethod
        def info(text):
            prefix = f"{Colors.green}[INFO]{Colors.reset} "
            message = f"{Colors.white}{text}"
            print(prefix + message)

        @staticmethod
        def error(text):
            prefix = f"{Colors.red}[ERROR]{Colors.reset} "
            message = f"{Colors.white}{text}"
            print(prefix + message)

        @staticmethod
        def success(text):
            prefix = f"{Colors.green}[SUCCESS]{Colors.reset} "
            message = f"{Colors.white}{text}"
            print(prefix + message)

        @staticmethod
        def warning(text):
            prefix = f"{Colors.yellow}[WARING]{Colors.reset} "
            message = f"{Colors.white}{text}"
            print(prefix + message)

        @staticmethod
        def ask(text):
            prefix = f"{Colors.yellow}[ASK]{Colors.reset} "
            message = f"{Colors.white}{text}"
            print(prefix + message)



import cloudscraper

def topup(phone, vouch):
    """
    This function redeems TrueMoney Wallet voucher by phone number and code.
    Uses Cloudscraper to bypass Cloudflare.
    """
    scraper = cloudscraper.create_scraper()
    payload = {
        "phone": phone,
        "vouch": vouch
    }

    r = scraper.post("https://api.kasawa.pro/api/wallet/topup", json=payload)
    return r



from setuptools import find_packages, setup

with open("./README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="kasawa",
    version="0.0.4",
    description="I Make module this for using for easy to work",
    packages=find_packages(),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/x2super/kasawa",
    author="x2super",
    author_email="kasawaonecap@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "requests",
        "cloudscraper",
        "pystyle"
    ],
    python_requires=">=3.10",
)

